#!/usr/bin/python
# read templateparser output and transform to man format
import sys

####
def get(line):
	return line.split(":", 1)[1].strip()
	
parameter = help = ptype = default = ""
while 1:
	line = sys.stdin.readline()
	if not line: break
	if line.find("section:") == 0:
		section = line.split()[1]
		print ".TP"
		print "\\fB* Section [%s]\\fR" %section
	elif line.find("parameter:") >= 0:
		parameter = get(line)
	elif line.find("default:") >= 0:
		default = get(line)
	elif line.find("type:") >= 0:
		ptype = get(line)
	elif line.find("help:") >= 0:
		help = get(line)
		print ".TP"
		print "%s: \\fI%s\\fR" %(parameter, ptype)
		print "%s." %help,
		if default: print "Default value: %s" %default
		else: print
		parameter = help = ptype = default = ""
	
print ".PP"
sys.exit(0)